@@ -10,27 +10,18 @@ from timely_beliefs.sensors.func_store.knowledge_horizons import (
 
 def test_fixed_knowledge_time():
     knowledge_time = datetime(2020, 11, 20, 0, tzinfo=utc)
-    assert (
-        determine_knowledge_horizon_for_fixed_knowledge_time(
-            event_start=datetime(2020, 11, 19, 0, tzinfo=utc),
-            knowledge_time=knowledge_time,
-        )
-        == timedelta(-1)
-    )
-    assert (
-        determine_knowledge_horizon_for_fixed_knowledge_time(
-            event_start=datetime(2020, 11, 20, 0, tzinfo=utc),
-            knowledge_time=knowledge_time,
-        )
-        == timedelta(0)
-    )
-    assert (
-        determine_knowledge_horizon_for_fixed_knowledge_time(
-            event_start=datetime(2020, 11, 21, 0, tzinfo=utc),
-            knowledge_time=knowledge_time,
-        )
-        == timedelta(1)
-    )
+    assert determine_knowledge_horizon_for_fixed_knowledge_time(
+        event_start=datetime(2020, 11, 19, 0, tzinfo=utc),
+        knowledge_time=knowledge_time,
+    ) == timedelta(-1)
+    assert determine_knowledge_horizon_for_fixed_knowledge_time(
+        event_start=datetime(2020, 11, 20, 0, tzinfo=utc),
+        knowledge_time=knowledge_time,
+    ) == timedelta(0)
+    assert determine_knowledge_horizon_for_fixed_knowledge_time(
+        event_start=datetime(2020, 11, 21, 0, tzinfo=utc),
+        knowledge_time=knowledge_time,
+    ) == timedelta(1)
 
 
 def test_dst():
